@@ -7,6 +7,7 @@ use Carp;
 use threads;
 
 use File::Basename;
+use File::Spec;
 use FindBin;
 use Getopt::Long qw(:config no_ignore_case bundling);
 use lib("$FindBin::Bin/../../PerlLib");
@@ -63,6 +64,7 @@ my $min_reads_per_partition = 10;
 my $parts_per_dir = 100;
 my $sort_buffer = '10G';
 
+my $SYMLINK = ($ENV{NO_SYMLINK}) ? "cp" : "ln -sf";
 
 &GetOptions ( 'h' => \$help_flag,
 
@@ -117,8 +119,8 @@ main: {
 		push (@sam_info, [$plus_strand_sam, '+'], [$minus_strand_sam, '-']);
 	}
 	else {
-        if (cwd() ne dirname($SAM_file)) {
-            &process_cmd("ln -sf $SAM_file");
+        if (cwd() ne dirname(File::Spec->rel2abs($SAM_file))) {
+            &process_cmd("$SYMLINK $SAM_file");
             $SAM_file = basename($SAM_file);
         }
 		push (@sam_info, [$SAM_file, '+']);
